==> phpBB-3.0.2_to_3.0.3-deutsch.zip: install/update/index.php <==
<?php

if (!defined('IN_PHPBB'))
{
	exit;
}

// Set update info with file structure to update
$update_info = array(
	'version'	=> array('from' => '3.0.2', 'to' => '3.0.3'),
'files'		=> array('adm/style/acp_ban.html',
	'adm/style/acp_groups.html',
	'adm/style/acp_main.html',
	'adm/style/acp_styles.html',
	'adm/style/acp_users_overview.html',
	'adm/style/admin.css',
	'adm/style/install_update.html',
	'adm/style/overall_header.html',
	'adm/style/permission_mask.html',
	'common.php',
	'download/file.php',
	'includes/acm/acm_file.php',
	'includes/acp/acp_attachments.php',
	'includes/acp/acp_bbcodes.php',
	'includes/acp/acp_board.php',
	'includes/acp/acp_captcha.php',
	'includes/acp/acp_database.php',
	'includes/acp/acp_forums.php',
	'includes/acp/acp_groups.php',
	'includes/acp/acp_icons.php',
	'includes/acp/acp_jabber.php',
	'includes/acp/acp_main.php',
	'includes/acp/acp_permissions.php',
	'includes/acp/acp_styles.php',
	'includes/acp/acp_users.php',
	'includes/acp/info/acp_email.php',
	'includes/auth.php',
	'includes/bbcode.php',
	'includes/constants.php',
	'includes/db/db_tools.php',
	'includes/db/dbal.php',
	'includes/db/firebird.php',
	'includes/db/mssql.php',
	'includes/db/mssql_odbc.php',
	'includes/db/mysql.php',
	'includes/db/mysqli.php',
	'includes/db/oracle.php',
	'includes/db/postgres.php',
	'includes/db/sqlite.php',
	'includes/diff/diff.php',
	'includes/diff/engine.php',
	'includes/diff/renderer.php',
	'includes/functions.php',
	'includes/functions_admin.php',
	'includes/functions_compress.php',
	'includes/functions_content.php',
	'includes/functions_convert.php',
	'includes/functions_display.php',
	'includes/functions_jabber.php',
	'includes/functions_messenger.php',
	'includes/functions_module.php',
	'includes/functions_posting.php',
	'includes/functions_privmsgs.php',
	'includes/functions_template.php',
	'includes/functions_upload.php',
	'includes/functions_user.php',
	'includes/mcp/mcp_forum.php',
	'includes/mcp/mcp_front.php',
	'includes/mcp/mcp_logs.php',
	'includes/mcp/mcp_main.php',
	'includes/mcp/mcp_post.php',
	'includes/mcp/mcp_queue.php',
	'includes/mcp/mcp_reports.php',
	'includes/mcp/mcp_topic.php',
	'includes/mcp/mcp_warn.php',
	'includes/message_parser.php',
	'includes/search/fulltext_mysql.php',
	'includes/search/fulltext_native.php',
	'includes/search/search.php',
	'includes/session.php',
	'includes/template.php',
	'includes/ucp/ucp_activate.php',
	'includes/ucp/ucp_groups.php',
	'includes/ucp/ucp_main.php',
	'includes/ucp/ucp_pm_compose.php',
	'includes/ucp/ucp_pm_viewfolder.php',
	'includes/ucp/ucp_prefs.php',
	'includes/ucp/ucp_profile.php',
	'includes/ucp/ucp_register.php',
	'includes/ucp/ucp_remind.php',
	'index.php',
	'language/en/acp/attachments.php',
	'language/en/acp/board.php',
	'language/en/acp/common.php',
	'language/en/acp/groups.php',
	'language/en/acp/permissions_phpbb.php',
	'language/en/acp/posting.php',
	'language/en/acp/styles.php',
	'language/en/common.php',
	'language/en/email/group_request.txt',
	'language/en/help_faq.php',
	'language/en/install.php',
	'language/en/mcp.php',
	'language/en/ucp.php',
	'language/en/viewtopic.php',
	'mcp.php',
	'memberlist.php',
	'posting.php',
	'search.php',
	'style.php',
	'styles/prosilver/imageset/imageset.cfg',
	'styles/prosilver/style.cfg',
	'styles/prosilver/template/faq_body.html',
	'styles/prosilver/template/forumlist_body.html',
	'styles/prosilver/template/mcp_forum.html',
	'styles/prosilver/template/mcp_front.html',
	'styles/prosilver/template/mcp_header.html',
	'styles/prosilver/template/mcp_post.html',
	'styles/prosilver/template/mcp_warn_post.html',
	'styles/prosilver/template/mcp_warn_user.html',
	'styles/prosilver/template/memberlist_body.html',
	'styles/prosilver/template/memberlist_leaders.html',
	'styles/prosilver/template/memberlist_view.html',
	'styles/prosilver/template/overall_footer.html',
	'styles/prosilver/template/overall_header.html',
	'styles/prosilver/template/search_results.html',
	'styles/prosilver/template/styleswitcher.js',
	'styles/prosilver/template/template.cfg',
	'styles/prosilver/template/ucp_groups_manage.html',
	'styles/prosilver/template/ucp_main_subscribed.html',
	'styles/prosilver/template/ucp_pm_history.html',
	'styles/prosilver/template/ucp_pm_viewmessage.html',
	'styles/prosilver/template/viewforum_body.html',
	'styles/prosilver/template/viewtopic_body.html',
	'styles/prosilver/theme/content.css',
	'styles/prosilver/theme/links.css',
	'styles/prosilver/theme/theme.cfg',
	'styles/subsilver2/imageset/imageset.cfg',
	'styles/subsilver2/style.cfg',
	'styles/subsilver2/template/faq_body.html',
	'styles/subsilver2/template/forumlist_body.html',
	'styles/subsilver2/template/index_body.html',
	'styles/subsilver2/template/mcp_ban.html',
	'styles/subsilver2/template/mcp_forum.html',
	'styles/subsilver2/template/mcp_front.html',
	'styles/subsilver2/template/mcp_post.html',
	'styles/subsilver2/template/mcp_warn_post.html',
	'styles/subsilver2/template/mcp_warn_user.html',
	'styles/subsilver2/template/memberlist_view.html',
	'styles/subsilver2/template/template.cfg',
	'styles/subsilver2/template/ucp_groups_manage.html',
	'styles/subsilver2/template/ucp_main_subscribed.html',
	'styles/subsilver2/template/ucp_pm_history.html',
	'styles/subsilver2/template/viewforum_body.html',
	'styles/subsilver2/template/viewtopic_body.html',
	'styles/subsilver2/theme/theme.cfg',
	'ucp.php',
	'viewforum.php',
	'viewonline.php',
	'viewtopic.php'),
'binary'		=> array(),
);

?><?php
//Dateien vom deutschen Sprachpaket
$update_info['files'] = array_merge($update_info['files'], array(
	'language/de/acp/attachments.php',
	'language/de/acp/board.php',
	'language/de/acp/common.php',
	'language/de/acp/forums.php',
	'language/de/acp/groups.php',
	'language/de/acp/permissions.php',
	'language/de/acp/permissions_phpbb.php',
	'language/de/acp/posting.php',
	'language/de/acp/styles.php',
	'language/de/common.php',
	'language/de/email/group_request.txt',
	'language/de/install.php',
	'language/de/mcp.php',
	'language/de/ucp.php',
	'language/de/viewtopic.php',
	'language/de_x_sie/acp/attachments.php',
	'language/de_x_sie/acp/board.php',
	'language/de_x_sie/acp/common.php',
	'language/de_x_sie/acp/forums.php',
	'language/de_x_sie/acp/groups.php',
	'language/de_x_sie/acp/permissions.php',
	'language/de_x_sie/acp/permissions_phpbb.php',
	'language/de_x_sie/acp/posting.php',
	'language/de_x_sie/acp/styles.php',
	'language/de_x_sie/common.php',
	'language/de_x_sie/email/group_request.txt',
	'language/de_x_sie/install.php',
	'language/de_x_sie/mcp.php',
	'language/de_x_sie/ucp.php',
	'language/de_x_sie/viewtopic.php',
));
$update_info['binary'] = array_merge($update_info['binary'], array(
));
?>

==> phpBB-3.0.3_to_3.0.4-deutsch.zip: install/update/index.php <==
<?php

if (!defined('IN_PHPBB'))
{
	exit;
}

// Set update info with file structure to update
$update_info = array(
	'version'	=> array('from' => '3.0.3', 'to' => '3.0.4'),
'files'		=> array('adm/style/acp_profile.html',
	'adm/style/install_update.html',
	'includes/acm/acm_file.php',
	'includes/acp/acp_main.php',
	'includes/acp/acp_modules.php',
	'includes/acp/acp_profile.php',
	'includes/acp/acp_styles.php',
	'includes/constants.php',
	'includes/db/dbal.php',
	'includes/functions.php',
	'includes/functions_admin.php',
	'includes/functions_content.php',
	'includes/functions_display.php',
	'includes/functions_messenger.php',
	'includes/functions_module.php',
	'includes/functions_posting.php',
	'includes/functions_profile_fields.php',
	'includes/mcp/mcp_queue.php',
	'includes/search/fulltext_native.php',
	'includes/session.php',
	'includes/ucp/ucp_activate.php',
	'includes/ucp/ucp_groups.php',
	'includes/ucp/ucp_main.php',
	'includes/ucp/ucp_pm_compose.php',
	'includes/ucp/ucp_pm_viewmessage.php',
	'language/en/acp/profile.php',
	'language/en/acp/search.php',
	'language/en/common.php',
	'language/en/install.php',
	'language/en/ucp.php',
	'memberlist.php',
	'styles/prosilver/imageset/imageset.cfg',
	'styles/prosilver/style.cfg',
	'styles/prosilver/template/forumlist_body.html',
	'styles/prosilver/template/mcp_forum.html',
	'styles/prosilver/template/mcp_front.html',
	'styles/prosilver/template/mcp_post.html',
	'styles/prosilver/template/mcp_queue.html',
	'styles/prosilver/template/mcp_reports.html',
	'styles/prosilver/template/memberlist_body.html',
	'styles/prosilver/template/memberlist_search.html',
	'styles/prosilver/template/posting_review.html',
	'styles/prosilver/template/posting_topic_review.html',
	'styles/prosilver/template/search_results.html',
	'styles/prosilver/template/simple_header.html',
	'styles/prosilver/template/template.cfg',
	'styles/prosilver/template/ucp_main_bookmarks.html',
	'styles/prosilver/template/ucp_main_front.html',
	'styles/prosilver/template/ucp_main_subscribed.html',
	'styles/prosilver/template/ucp_pm_history.html',
	'styles/prosilver/template/ucp_pm_viewfolder.html',
	'styles/prosilver/template/viewforum_body.html',
	'styles/prosilver/template/viewtopic_body.html',
	'styles/prosilver/theme/theme.cfg',
	'styles/subsilver2/imageset/imageset.cfg',
	'styles/subsilver2/style.cfg',
	'styles/subsilver2/template/template.cfg',
	'styles/subsilver2/theme/theme.cfg',
	'viewtopic.php'),
'binary'		=> array(),
);

?><?php
//Dateien vom deutschen Sprachpaket
$update_info['files'] = array_merge($update_info['files'], array(
	'language/de/acp/profile.php',
	'language/de/acp/search.php',
	'language/de/common.php',
	'language/de/install.php',
	'language/de/ucp.php',
	'language/de_x_sie/acp/profile.php',
	'language/de_x_sie/acp/search.php',
	'language/de_x_sie/common.php',
	'language/de_x_sie/install.php',
	'language/de_x_sie/ucp.php',
));
$update_info['binary'] = array_merge($update_info['binary'], array(
));
?>
